==> appops-br-service-base-0.3.0-sources.jar: org/appops/service/CurrentDeploymentProvider.java <==
/*
 * AppOps is a Java framework to develop, deploy microservices with ease and is available for free
 * and common use developed by AinoSoft ( www.ainosoft.com )
 *
 * AppOps and AinoSoft are registered trademarks of Aino Softwares private limited, India.
 *
 * Copyright (C) <2016> <Aino Softwares private limited>
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version along with applicable additional terms as
 * provisioned by GPL 3.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License and applicable additional terms
 * along with this program.
 *
 * If not, see <https://www.gnu.org/licenses/> and <https://www.appops.org/license>
 */

package org.appops.service;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.appops.core.annotation.Config;
import org.appops.core.deployment.DeploymentConfig;

/**
 * <p>
 * CurrentDeploymentProvider class.
 * </p>
 *
 * @author deba
 * @version $Id: $Id
 */
public class CurrentDeploymentProvider implements Provider<DeploymentConfig> {

  private DeploymentConfig currentDeployment;

  /** {@inheritDoc} */
  @Override
  public DeploymentConfig get() {
    return getCurrentDeployment();
  }

  /**
   * <p>
   * Getter for the field <code>currentDeployment</code>.
   * </p>
   *
   * @return a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  public DeploymentConfig getCurrentDeployment() {
    return currentDeployment;
  }

  /**
   * <p>
   * Setter for the field <code>currentDeployment</code>.
   * </p>
   *
   * @param currentDeployment a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  @Inject
  public void setCurrentDeployment(@Config DeploymentConfig currentDeployment) {
    this.currentDeployment = currentDeployment;
  }

}

==> appops-br-service-base-0.4.0-sources.jar: org/appops/service/CurrentDeploymentProvider.java <==
/*
 * AppOps is a Java framework to develop, deploy microservices with ease and is available for free
 * and common use developed by AinoSoft ( www.ainosoft.com )
 *
 * AppOps and AinoSoft are registered trademarks of Aino Softwares private limited, India.
 *
 * Copyright (C) <2016> <Aino Softwares private limited>
 *
 * This program is free software: you can redistribute it and/or modify it under the terms of the
 * GNU General Public License as published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version along with applicable additional terms as
 * provisioned by GPL 3.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License and applicable additional terms
 * along with this program.
 *
 * If not, see <https://www.gnu.org/licenses/> and <https://www.appops.org/license>
 *
 *
 */

package org.appops.service;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.appops.core.annotation.Config;
import org.appops.core.deployment.ServiceConfiguration;

/**
 * <p>
 * CurrentDeploymentProvider class.
 * </p>
 *
 * @author deba
 * @version $Id: $Id
 */
public class CurrentDeploymentProvider implements Provider<ServiceConfiguration> {

  private ServiceConfiguration currentDeployment;

  /** {@inheritDoc} */
  @Override
  public ServiceConfiguration get() {
    return getCurrentDeployment();
  }

  /**
   * <p>
   * Getter for the field <code>currentDeployment</code>.
   * </p>
   *
   * @return a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  public ServiceConfiguration getCurrentDeployment() {
    return currentDeployment;
  }

  /**
   * <p>
   * Setter for the field <code>currentDeployment</code>.
   * </p>
   *
   * @param currentDeployment a {@link org.appops.core.deployment.DeploymentConfig} object.
   */
  @Inject
  public void setCurrentDeployment(@Config ServiceConfiguration currentDeployment) {
    this.currentDeployment = currentDeployment;
  }

}
